@@ -27,6 +27,10 @@ class AppConfig(BaseSettings):
     LOG_AS_JSON: bool = False
     EXPOSE_PII: bool = False
 
+    # GZIP
+    GZIP_MINIMUM_SIZE: int = 1000
+    GZIP_COMPRESSLEVEL: int = 5
+
     # Dockerization specific settings
     IS_DOCKERIZED: bool = False
     BUCKET_NAME: str | None = None
