@@ -47,7 +47,7 @@ class FastApiHandler:
     async def query(self, request: Request) -> Response:
         payload = await request.json()
         query_user_config = self.calculate_query_user_config(request)
-        query_result = self.__rest_handler._query_handler(payload, request.url.path, query_user_config)
+        query_result = await self.__rest_handler._query_handler(payload, request.url.path, query_user_config)
         logger.debug(
             "queried data",
             path=request.url.path,
