@@ -14,9 +14,9 @@
 
 import json
 import os
-from typing import Any
 
 import structlog
+from beartype.typing import Any
 
 logger = structlog.getLogger(__name__)
 
